@@ -1,28 +1,26 @@
+/* $Revision: 1.3 $ */
 /*
-
-    ``gpgp'' Gnome/GTK Front for PGP
-    Copyright (C) 1998  Max Valianskiy
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
-    $Id: main.c,v 1.3 1998/09/16 19:18:14 maxcom Stab $ 
-
-*/
-
+ * "gpgp" Gnome/GTK Front for PGP
+ * Copyright (C) 1998  Max Valianskiy
+ * Copyright (C) 1999 tftp@netscape.net
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free
+ * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ * History:
+ */
 #include "../config.h"
-#include "../version.h"
 
 #include <sys/types.h>
 #include <sys/mman.h>
@@ -82,15 +80,17 @@ int restarted = 0;
 int just_exit = 0;
 
 /* These are the arguments that our application supports. */
+#define DISCARD_KEY -1
+#if 0
+struct argp_option
+{
+};
 static struct argp_option arguments[] =
 {
-#define DISCARD_KEY -1
   { "discard-session", DISCARD_KEY, N_("ID"), 0, N_("Discard session"), 1 },
   { NULL, 0, NULL, 0, NULL, 0 }
 };
 
-static error_t parse_an_arg (int key, char *arg, struct argp_state *state); 
-
 static struct argp parser =
 {
   arguments,                    /* Options.  */
@@ -103,8 +103,9 @@ static struct argp parser =
   NULL                          /* Translation domain; for the app it
                                    can always be NULL.  */
 };
-
+static error_t parse_an_arg (int key, char *arg, struct argp_state *state); 
 void parse_args (int argc, char *argv[]);
+#endif
 
 GnomeUIInfo helpmenu[] = {
             {GNOME_APP_UI_ITEM, 
@@ -219,134 +220,155 @@ int error=0;
 int
 main(int argc, char *argv[])
 {
-  GnomeClient *client;   
+    GnomeClient *client;   
 
-  argp_program_version = VERSION;
+  /* argp_program_version = VERSION; */
 
-  options.rings = g_list_alloc();
+    options.rings = g_list_alloc();
 
-  /* i18n */
-  bindtextdomain (PACKAGE, LOCALEDIR);
-  textdomain (PACKAGE);
+    /* i18n */
+#if 1
+    bindtextdomain (PACKAGE, LOCALEDIR);
+    textdomain (PACKAGE);
+#endif
+    /* init gnome and parse params */
+#if 0
+    gnome_init ("gpgp", NULL /*&parser*/, argc, argv, 0, NULL);
+#else
+    gnome_init("gpgp", VERSION, argc, argv);
+#endif
 
-  client = gnome_client_new_default();
+    /* client = gnome_client_new_default(); */
+    client = gnome_client_new();
 
-  gtk_signal_connect (GTK_OBJECT (client), "save_yourself",
-                GTK_SIGNAL_FUNC (save_state), (gpointer) argv[0]);
-  gtk_signal_connect (GTK_OBJECT (client), "connect",
-                GTK_SIGNAL_FUNC (connect_client), NULL);
+    gtk_signal_connect (
+        GTK_OBJECT (client), "save_yourself",
+        GTK_SIGNAL_FUNC (save_state), (gpointer) argv[0]);
+    gtk_signal_connect (
+        GTK_OBJECT (client), "connect",
+        GTK_SIGNAL_FUNC (connect_client), NULL);
 
-  /* init gnome and parse params */
-  gnome_init ("gpgp", &parser, argc, argv,
-	      0, NULL);
-
-  /* prepare_app() makes all the gtk calls necessary to set up a
-     minimal Gnome application */
-  
-  if (!just_exit)
+    /*
+     * prepare_app() makes all the gtk calls necessary to set up a
+     * minimal Gnome application
+     */
+    if (!just_exit)
     {
-     prepare_app ();
-     gtk_main ();
+        prepare_app ();
+        gtk_main ();
     }
-
-  return 0;
+    return 0;
 }
 
 /************************/
 /*   Prepare applicaton */
 /************************/
 
-void
-prepare_app()
+void prepare_app()
 {
-  GtkWidget* mainbox;
+    GtkWidget* mainbox;
 
-  app = GNOME_APP(gnome_app_new ("gpgp", "Gnome PGP"));
+    app = GNOME_APP(gnome_app_new ("gpgp", "Gnome PGP"));
 
-  /* GnomePgp init */
-  gpgp_init(app, 1);
+    /* GnomePgp init */
+    gpgp_init(app, 1);
   
-  gtk_widget_set_events(GTK_WIDGET(app), GDK_KEY_PRESS_MASK | GDK_BUTTON_PRESS_MASK);
-  gtk_widget_realize (GTK_WIDGET(app));
-  gtk_signal_connect (GTK_OBJECT (app), "delete_event",
-                      GTK_SIGNAL_FUNC (quit_cb),
-                      NULL);
-
-  if (restarted) 
+    gtk_widget_set_events(GTK_WIDGET(app),
+                          GDK_KEY_PRESS_MASK | GDK_BUTTON_PRESS_MASK);
+    gtk_widget_realize (GTK_WIDGET(app));
+    gtk_signal_connect (GTK_OBJECT (app), "delete_event",
+                        GTK_SIGNAL_FUNC (quit_cb),
+                        NULL);
+    if (restarted) 
     {
-     gtk_widget_set_uposition (GTK_WIDGET(app), options.x, options.y);
-     gtk_widget_set_usize     (GTK_WIDGET(app), options.w, options.h);
+        gtk_widget_set_uposition (GTK_WIDGET(app), options.x, options.y);
+        gtk_widget_set_usize     (GTK_WIDGET(app), options.w, options.h);
     }
     else
     {
-     void* s;
-     char* key;
-     char* value;
+        void* s;
+        char* key;
+        char* value;
   
-     /* create rings section */
-     if (!gnome_config_has_section("gpgp-app/rings"))
-       {
-        gnome_config_set_string("gpgp-app/rings/0", gpgp_options.defpub);
-        gnome_config_set_string("gpgp-app/rings/1", gpgp_options.defsec);
-       }
+        /* create rings section */
+        if (!gnome_config_has_section("gpgp-app/rings"))
+        {
+            gnome_config_set_string("gpgp-app/rings/0", gpgp_options.defpub);
+            gnome_config_set_string("gpgp-app/rings/1", gpgp_options.defsec);
+        }
 
-     s = gnome_config_init_iterator("gpgp-app/rings");
-     while (gnome_config_iterator_next(s, &key, &value))
-     options.rings = g_list_append(options.rings,value);
+        s = gnome_config_init_iterator("gpgp-app/rings");
+        while (gnome_config_iterator_next(s, &key, &value))
+            options.rings = g_list_append(options.rings,value);
     }
 
-/* create menus */
-  gnome_app_create_menus(app, mainmenu);
-  gtk_widget_set_sensitive( filemenu[2].widget, FALSE ); /* CANCEL */
+    /* Create menus */
+    gnome_app_create_menus(app, mainmenu);
+    gtk_widget_set_sensitive( filemenu[2].widget, FALSE ); /* CANCEL */
 
-/* create statusbar */
-  gnome_app_set_statusbar(app, gnome_appbar_new(TRUE, TRUE, GNOME_PREFERENCES_USER));
+    /* Create statusbar */
+    gnome_app_set_statusbar(
+        app, gnome_appbar_new(TRUE, TRUE, GNOME_PREFERENCES_USER));
 
-/* set toolbar at left side by default */
-  gnome_config_set_string("gpgp/Placement/Toolbar",gnome_config_get_string("gpgp/Placement/Toolbar=left"));
+    /* Set toolbar at left side by default */
+    gnome_config_set_string(
+        "gpgp/Placement/Toolbar",
+        gnome_config_get_string("gpgp/Placement/Toolbar=left"));
 
-/* create toolbar */
-  gnome_app_create_toolbar(app, toolbar);
+    /* Create toolbar */
+    gnome_app_create_toolbar(app, toolbar);
 	
-/* create main box */  
-  mainbox = gtk_vbox_new (FALSE, 0);
-  gnome_app_set_contents (GNOME_APP(app), mainbox);
+    /* Create main box */  
+    mainbox = gtk_vbox_new (FALSE, 0);
+    gnome_app_set_contents (GNOME_APP(app), mainbox);
 
-/* create notebook */
-  mainwin.notebook = GTK_NOTEBOOK(gtk_notebook_new());
-  gtk_notebook_set_tab_pos(mainwin.notebook, GTK_POS_TOP);
-  gtk_widget_set_usize(GTK_WIDGET(mainwin.notebook), 600, 200);
-  gtk_box_pack_start(GTK_BOX(mainbox), GTK_WIDGET(mainwin.notebook), TRUE, TRUE, 0); 
+    /* create notebook */
+    mainwin.notebook = GTK_NOTEBOOK(gtk_notebook_new());
+    gtk_notebook_set_tab_pos(mainwin.notebook, GTK_POS_TOP);
+    gtk_widget_set_usize(GTK_WIDGET(mainwin.notebook), 600, 200);
+    gtk_box_pack_start(GTK_BOX(mainbox), GTK_WIDGET(mainwin.notebook), TRUE, TRUE, 0); 
 
-/* create keyrings page */
-  g_list_foreach(options.rings, addring, NULL);
+    /* Create keyrings page */
+    g_list_foreach(options.rings, addring, NULL);
+    gtk_notebook_set_page(mainwin.notebook,0);
 
-  gtk_notebook_set_page(mainwin.notebook,0);
-
-/* show app */
-  gtk_widget_show_all (GTK_WIDGET(app));
+    /* Show app */
+    gtk_widget_show_all (GTK_WIDGET(app));
 }
 
+/*
+ * addring()
+ *
+ * Procedure creates new GNOME_PGP_KEYRING object, populates
+ * it with key data and adds it to the keyring notebook control.
+ *
+ */
 void addring(gpointer data, gpointer user_data)
 {
-  GtkWidget* keyringpage;
+    GtkWidget* keyringpage;
 
-  if (!data)
-     return;
+    if (!data)
+        return;
 
-  keyringpage = gnome_pgp_keyring_new();
-  gtk_signal_connect (GTK_OBJECT (keyringpage), "error",GTK_SIGNAL_FUNC (report_error),NULL);
-  error=0;
-  gnome_pgp_keyring_select(GNOME_PGP_KEYRING(keyringpage), data);
-  if (!error)
+    keyringpage = gnome_pgp_keyring_new();
+    gtk_signal_connect(
+        GTK_OBJECT (keyringpage),
+        "error",
+        GTK_SIGNAL_FUNC (report_error),NULL);
+    error=0;
+    gnome_pgp_keyring_select(GNOME_PGP_KEYRING(keyringpage), data);
+    if (!error)
     {
-     gtk_notebook_prepend_page(GTK_NOTEBOOK(mainwin.notebook), keyringpage, gtk_label_new(g_basename(data)));
-     gtk_widget_show (keyringpage);
-     gtk_widget_set_sensitive( filemenu[2].widget, TRUE); /* CLOSE */
-     gtk_widget_set_sensitive( toolbar[2].widget, TRUE); /* CLOSE2 */
+        gtk_notebook_prepend_page(
+            GTK_NOTEBOOK(mainwin.notebook),
+            keyringpage,
+            gtk_label_new(g_basename(data)));
+        gtk_widget_show (keyringpage);
+        gtk_widget_set_sensitive( filemenu[2].widget, TRUE); /* CLOSE */
+        gtk_widget_set_sensitive( toolbar[2].widget, TRUE); /* CLOSE2 */
     }
     else
-     gtk_widget_destroy(GTK_WIDGET(keyringpage));
+        gtk_widget_destroy(GTK_WIDGET(keyringpage));
 }
 
 /************************/
@@ -858,23 +880,20 @@ int savering_n=0;
 
 void savering(GtkNotebookPage* page, char* name)
 {
- char buf[1000];
-
- g_snprintf(buf,sizeof(buf),"%s/%d", name, savering_n++);
-
- printf("%s=%s\n", buf, GNOME_PGP_KEYRING(page->child)->name);
- 
- gnome_config_set_string(buf, GNOME_PGP_KEYRING(page->child)->name);
+    char buf[1000];
+    g_snprintf(buf,sizeof(buf),"%s/%d", name, savering_n++);
+    printf("%s=%s\n", buf, GNOME_PGP_KEYRING(page->child)->name);
+    gnome_config_set_string(buf, GNOME_PGP_KEYRING(page->child)->name);
 }
 
-static int
-save_state (GnomeClient        *client,
-            gint                phase,
-            GnomeRestartStyle   save_style,
-            gint                shutdown,
-            GnomeInteractStyle  interact_style,
-            gint                fast,
-            gpointer            client_data)
+static int save_state(
+    GnomeClient        *client,
+    gint                phase,
+    GnomeRestartStyle   save_style,
+    gint                shutdown,
+    GnomeInteractStyle  interact_style,
+    gint                fast,
+    gpointer            client_data)
 {
   gchar *session_id;
   gchar *sess;
@@ -922,11 +941,11 @@ save_state (GnomeClient        *client,
 
   gnome_config_sync();
  
-  /* Here is the real SM code. We set the argv to the parameters need
-ed
-     to restart/discard the session that we've just saved and call
-     the gnome_session_set_*_command to tell the session manager it.
-*/
+  /*
+   * Here is the real SM code. We set the argv to the parameters needed
+   * to restart/discard the session that we've just saved and call
+   * the gnome_session_set_*_command to tell the session manager it.
+   */
   argv[0] = (char*) client_data;
   argv[1] = "--discard-session";
   argv[2] = session_id;
@@ -943,89 +962,99 @@ e
   return TRUE;
 }
 
-/* Connected to session manager. If restarted from a former session:
-   reads the state of the previous session. Sets os_* (prepare_app
-   uses them) */
-void
-connect_client (GnomeClient *client, gint was_restarted, gpointer client_data)
+/*
+ * Connected to session manager. If restarted from a former session:
+ * reads the state of the previous session. Sets os_* (prepare_app
+ * uses them)
+ */
+void connect_client(
+    GnomeClient *client,
+    gint was_restarted,
+    gpointer client_data)
 {
-  gchar *session_id;
+    gchar *session_id;
 
-  /* Note that information is stored according to our *old*
-     session id.  The id can change across sessions.  */
-  session_id = gnome_client_get_previous_id (client);
-
-  if (was_restarted && session_id != NULL)
+    /*
+     * Note that information is stored according to our _old_
+     * session id.  The id can change across sessions.
+     */
+    session_id = gnome_client_get_previous_id (client);
+    if (was_restarted && session_id != NULL)
     {
-      gchar *sess;
-      gchar *buf;
-      void  *s;
-      char* key;
-      char* value;
+        gchar *sess;
+        gchar *buf;
+        void  *s;
+        char* key;
+        char* value;
  
-      restarted = 1;
+        restarted = 1;
 
-      sess = g_copy_strings ("/gpgp-app/Saved-Session-", session_id, NULL);
+        sess = g_copy_strings ("/gpgp-app/Saved-Session-", session_id, NULL);
 
-      buf = g_copy_strings ( sess, "/x", NULL);
-      options.x = gnome_config_get_int (buf);
-      g_free(buf);
-      buf = g_copy_strings ( sess, "/y", NULL);
-      options.y = gnome_config_get_int (buf);
-      g_free(buf);
-      buf = g_copy_strings ( sess, "/w", NULL);
-      options.w = gnome_config_get_int (buf);
-      g_free(buf);
-      buf = g_copy_strings ( sess, "/h", NULL);
-      options.h = gnome_config_get_int (buf);
-      g_free(buf);
+        buf = g_copy_strings ( sess, "/x", NULL);
+        options.x = gnome_config_get_int (buf);
+        g_free(buf);
 
-      g_free(sess);
+        buf = g_copy_strings ( sess, "/y", NULL);
+        options.y = gnome_config_get_int (buf);
+        g_free(buf);
 
-    /* rings */
-      sess = g_copy_strings("/gpgp-app/rings-Saved-Session-", session_id, NULL);
+        buf = g_copy_strings ( sess, "/w", NULL);
+        options.w = gnome_config_get_int (buf);
+        g_free(buf);
+
+        buf = g_copy_strings ( sess, "/h", NULL);
+        options.h = gnome_config_get_int (buf);
+        g_free(buf);
+
+        g_free(sess);
+
+        /* Rings */
+        sess = g_copy_strings("/gpgp-app/rings-Saved-Session-", session_id, NULL);
       
-      s = gnome_config_init_iterator(sess);
-      while (gnome_config_iterator_next(s, &key, &value))
-        options.rings = g_list_append(options.rings,value);
-      g_free(sess);
+        s = gnome_config_init_iterator(sess);
+        while (gnome_config_iterator_next(s, &key, &value))
+        {
+            options.rings = g_list_append(options.rings,value);
+        }
+        g_free(sess);
     }
 
-  /* If we had an old session, we clean up after ourselves.  */
-  if (session_id != NULL)
-    discard_session (session_id);
-
-  return;
+    /* If we had an old session, we clean up after ourselves.  */
+    if (session_id != NULL)
+        discard_session (session_id);
+    return;
 }
 
-void
-discard_session (gchar *id)
+void discard_session (gchar *id)
 {
-  gchar *sess;
+    gchar *sess;
 
-  sess = g_copy_strings ("/gpgp-app/Saved-Session-", id, NULL);
+    sess = g_copy_strings ("/gpgp-app/Saved-Session-", id, NULL);
 
-  /* we use the gnome_config_get_* to work around a bug in gnome-conf
-ig
-     (it's going under a redesign/rewrite, so i didn't correct it) */
-  gnome_config_get_int ("/gpgp-app/Bug/work-around=0");
-  gnome_config_clean_section (sess);
-  g_free (sess);
+    /*
+     * We use the gnome_config_get_* to work around a
+     * bug in gnome-config (it's going under a redesign/rewrite,
+     * so i didn't correct it) [Max]
+     */
+    gnome_config_get_int ("/gpgp-app/Bug/work-around=0");
+    gnome_config_clean_section (sess);
+    g_free (sess);
 
-  sess = g_copy_strings ("/gpgp-app/rings-Saved-Session-", id, NULL);
-  gnome_config_get_int ("/gpgp-app/Bug/work-around=0");
-  gnome_config_clean_section (sess);
-  g_free (sess);
+    sess = g_copy_strings ("/gpgp-app/rings-Saved-Session-", id, NULL);
+    gnome_config_get_int ("/gpgp-app/Bug/work-around=0");
+    gnome_config_clean_section (sess);
+    g_free (sess);
   
-  gnome_config_sync ();
+    gnome_config_sync ();
 
-  return;
+    return;
 }
 
 /***************************/
 /* Options parseing        */
 /***************************/
-
+#if 0
 static error_t
 parse_an_arg (int key, char *arg, struct argp_state *state)
 {
@@ -1039,14 +1068,12 @@ parse_an_arg (int key, char *arg, struct argp_state *state)
   /* We didn't recognize it.  */
   return ARGP_ERR_UNKNOWN;
 }
+#endif
 
 void lib_properties_cb (GtkWidget *widget, void *data)
 {
- GtkWidget *properties;
-
- gnome_app_warning(app, _("This feature is under construction")); 
-
- properties = gnome_pgp_lib_properties_new();
-
- gtk_widget_show(properties);
+    GtkWidget *properties;
+    gnome_app_warning(app, _("This feature is under construction")); 
+    properties = gnome_pgp_lib_properties_new();
+    gtk_widget_show(properties);
 }
